@@ -4,7 +4,7 @@ use namespace::clean;
 use Unix::Statgrab;
 use List::Util qw( min max );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 extends 'Parallel::ForkManager';
 
@@ -219,7 +219,7 @@ Parallel::ForkManager::Scaled - Run processes in parallel based on CPU usage
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 SYNOPSIS
 
@@ -499,11 +499,7 @@ which is probably any system where the libstatgrab library can compile.
 
 =head1 AUTHOR
 
-=over
-
-=item Jason McCarver <slam@parasite.cc>
-
-=back
+Jason McCarver <slam@parasite.cc>
 
 =head1 SEE ALSO
 
